summaryrefslogtreecommitdiff
path: root/fml
diff options
context:
space:
mode:
authorfukachan <fukachan>2004-03-28 12:13:52 +0000
committerfukachan <fukachan>2004-03-28 12:13:52 +0000
commite1ff8918b2690864c024a9722bb281c4bd1391cc (patch)
treec1de115b5786a872292f86b4d4b8587ade552e3b /fml
parent71fb31528e5e73a85729b066ccb7474793d98724 (diff)
downloadfml8-e1ff8918b2690864c024a9722bb281c4bd1391cc.tar.gz
fml8-e1ff8918b2690864c024a9722bb281c4bd1391cc.tar.bz2
fml8-e1ff8918b2690864c024a9722bb281c4bd1391cc.zip
define {set,get}_article_summary() and article_summary db to handle
article summary easily.
Diffstat (limited to 'fml')
-rw-r--r--fml/lib/Mail/Message/DB.pm5
-rw-r--r--fml/lib/Mail/Message/Thread.pm30
2 files changed, 31 insertions, 4 deletions
diff --git a/fml/lib/Mail/Message/DB.pm b/fml/lib/Mail/Message/DB.pm
index 58f4ff4f..eafc797c 100644
--- a/fml/lib/Mail/Message/DB.pm
+++ b/fml/lib/Mail/Message/DB.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: DB.pm,v 1.16 2004/03/27 09:28:06 fukachan Exp $
+# $FML: DB.pm,v 1.17 2004/03/28 10:28:23 fukachan Exp $
#
package Mail::Message::DB;
@@ -21,7 +21,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD
use Carp;
use File::Spec;
-my $version = q$FML: DB.pm,v 1.16 2004/03/27 09:28:06 fukachan Exp $;
+my $version = q$FML: DB.pm,v 1.17 2004/03/28 10:28:23 fukachan Exp $;
if ($version =~ /,v\s+([\d\.]+)\s+/) { $version = $1;}
# special value
@@ -81,6 +81,7 @@ my $is_demand_copying = 1;
thread_status
article_status
+ article_summary
);
diff --git a/fml/lib/Mail/Message/Thread.pm b/fml/lib/Mail/Message/Thread.pm
index b0d04a5f..421be469 100644
--- a/fml/lib/Mail/Message/Thread.pm
+++ b/fml/lib/Mail/Message/Thread.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Thread.pm,v 1.3 2004/03/27 09:23:07 fukachan Exp $
+# $FML: Thread.pm,v 1.4 2004/03/28 10:28:23 fukachan Exp $
#
package Mail::Message::Thread;
@@ -196,7 +196,7 @@ sub get_thread_status
}
# Descriptions: set thread status.
# Arguments: OBJ($self) NUM($id) STR($status)
# Side Effects: update UDB
# Return Value: none
@@ -222,6 +222,32 @@ sub get_article_status
}
+# Descriptions: set article summary.
+# Arguments: OBJ($self) NUM($id) STR($summary)
+# Side Effects: update UDB
+# Return Value: none
+sub set_article_summary
+{
+ my ($self, $id, $summary) = @_;
+ my $db = $self->db();
+
+ $db->set('article_summary', $id, $summary);
+}
+
+
+# Descriptions: get article summary.
+# Arguments: OBJ($self) NUM($id)
+# Side Effects: none
+# Return Value: STR
+sub get_article_summary
+{
+ my ($self, $id) = @_;
+ my $db = $self->db();
+
+ $db->get('article_summary', $id);
+}
+
+
=head1 TODO
=head1 CODING STYLE
@@ -196,7 +196,7 @@ sub get_thread_status
}
-# Descriptions: set thread status.
+# Descriptions: set article status.
# Arguments: OBJ($self) NUM($id) STR($status)
# Side Effects: update UDB